import { BasicColumn } from '/@/components/Table';
import { FormSchema } from '/@/components/Table';
import { optionsListApi,optionsListApiType } from '/@/api/tigerapi/mes/smt/tool';
import { h,unref } from 'vue';
import { Tag ,Tooltip} from 'ant-design-vue';
import{ useLocale } from '/@/locales/useLocale';

const { getLocale }=useLocale();

export const columns: BasicColumn[] = [
  {
    title: '条码',
    dataIndex: 'TOOL_CODE',
    width:200,
    sorter: true,
    resizable:true
  },
  {
    title: '型号',
    dataIndex: 'TOOL_MODEL',
    width: 100,
    sorter: true,
    resizable:true
  },
  {
    title: '描述',
    dataIndex: 'TOOL_SPEC',
    width: 200,
    sorter: true,
    resizable:true
  },
  {
    title: '类型',
    dataIndex: 'TYPE',
    width: 100,
    sorter: true,
    resizable: true,
    customRender: ({ record }) => {
      const status = record.TYPE;
      var text = '';
      var color = '';
      switch (status) {
        case 0:
          text = '钢网';
          color = 'green';
          break;
        case 1:
          text = '刮刀';
          color = 'blue';
          break;
        default:
          break;
      }
      return h(Tooltip, { title: 'xxxxxx' }, () => h(Tag, { color: color }, () => text));
    },
  },
  {
    title: '预警列表',
    dataIndex: 'ALARM_TYPE',
    width: 100,
    sorter: true,
    resizable: true,
    customRender: ({ record }) => {
      const status = record.ALARM_TYPE;
      var text = '';
      var color = '';
      switch (status) {
        case '0':
          text = '正常';
          color = 'green';
          break;
        case '1':
          text = '保养预警';
          color = 'blue';
          break;
        case '2':
          text = '报废预警';
          color = 'blue';
          break;
        default:
          break;
      }
      return h(Tooltip, { title: 'xxxxxx' }, () => h(Tag, { color: color }, () => text));
    },
  },
  {
    title: '制造商',
    dataIndex: 'MANUFACTURER',
    width:100,
    sorter: true,
    resizable:true
  },
  {
    title: '当前使用次数',
    dataIndex: 'USE_COUNT',
    width:100,
    sorter: true,
    resizable:true
  }
  ,
  {
    title: '累计次数',
    dataIndex: 'TOTAL',
    width:100,
    sorter: true,
    resizable:true
  }
  ,
  {
    title: '状态',
    dataIndex: 'STATUS',
    width: 100,
    sorter: true,
    resizable: true,
    customRender: ({ record }) => {
      const status = record.STATUS;
      var text = '';
      var color = '';
      switch (status) {
        case 0:
          text = '已入库';
          color = 'green';
          break;
        case 1:
          text = '已领用';
          color = 'blue';
          break;
        case 2:
          text = '已上线';
          color = 'blue';
          break;
        case 3:
          text = '已下线';
          color = 'blue';
          break;
        case 4:
          text = '保养中';
          color = 'blue';
          break;
        case 5:
          text = '已报废';
          color = 'blue';
          break;
        default:
          break;
      }
      return h(Tooltip, { title: 'xxxxxx' }, () => h(Tag, { color: color }, () => text));
    },
  },
  {
    title: '创建人',
    dataIndex: 'CREATE_USER',
    width:100,
    sorter: true,
    resizable:true
  },
  {
    title: '创建时间',
    dataIndex: 'CREATE_TIME',
    width:100,
    sorter: true,
    resizable:true
  }
];

export const searchFormSchema: FormSchema[] = [
  {
    field: 'TOOL_CODE',
    label: '条码',
    component: 'Input',
    colProps: { span: 8 },
  },
 
  {
    field: 'ALARM_TYPE',
    label: '预警列表',
    component: 'ApiSelect',
    colProps: { span: 8 },
    componentProps: {
      api: optionsListApi,
      resultField: 'Data',
      labelField: unref(getLocale)=='zh_CN'?'Desc':'Name',
      valueField: 'Value',
    },
  },
 
  {
    field: 'MANUFACTURER',
    label: '制造商',
    component: 'Input',
    colProps: { span: 8 },
  },
 
  {
    field: 'TOOL_MODEL',
    label: '型号',
    component: 'Input',
    colProps: { span: 8 },
  }
];

//新增组件export const
export const formSchema: FormSchema[] = [
  {
    field: 'TOOL_CODE',
    label: '条码',
    required: true,
    component: 'Input',
    colProps: { span: 12 },
  },
  {
    field: 'ID',
    label: 'ID',
    component: 'Input',
    show: false,
  },
  {
    field: 'TOOL_MODEL',
    label: '型号',
    component: 'Input',
    show: false,
    colProps: { span: 12 },
  },
  {
    field: 'TOOL_SPEC',
    label: '描述',
    required: true,
    component: 'Input',
    colProps: { span: 12 },
  },
  {
    field: 'TYPE',
    label: '类型',
    component: 'ApiSelect',
    colProps: { span: 12 },
    componentProps: {
      api: optionsListApiType,
      resultField: 'Data',
      labelField: unref(getLocale)=='zh_CN'?'Desc':'Name',
      valueField: 'Value',
    },
  },
  {
    field: 'MANUFACTURER',
    label: '制造商',
    //required: true,
    component: 'Input',
    colProps: { span: 12 },
  },
  {
    field: 'USE_LIMIT',
    label: '使用上限',
    required: true,
    component: 'Input',
    colProps: { span: 12 },
  },
  {
    field: 'MT_ALARM_NO',
    label: '保养预警次数',
    //required: true,
    component: 'Input',
    colProps: { span: 12 },
  },
  {
    field: 'SCRAP_ALARM_NO',
    label: '报废预警次数',
    //required: true,
    component: 'Input',
    colProps: { span: 12 },
  },
  {
    field: 'WH_CODE',
    label: '仓位',
    //required: true,
    component: 'Input',
    colProps: { span: 12 },
  },
  {
    field: 'REGION_CODE',
    label: '储位',
    required: true,
    component: 'Input',
    colProps: { span: 12 },
  }
];
